/******************** (C) COPYRIGHT 2011 STMicroelectronics ********************
* File Name          : usb_endp.c
* Author             : MCD Application Team
* Version            : V3.3.0
* Date               : 21-March-2011
* Description        : Endpoint routines
********************************************************************************
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "usb_lib.h"
#include "usb_desc.h"
#include "usb_mem.h"
#include "hw_config.h"
#include "usb_istr.h"
#include "usb_pwr.h"

#include "libraries.h"

extern volatile TypeDef_USB_Mode        USB_Mode;
extern  uint16_t                        USB_Len;
extern  char *                          USB_Data;

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/

/* Interval between sending IN packets in frame number (1 frame = 1ms) */
#define VCOMPORT_IN_FRAME_INTERVAL             5

/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
uint8_t USB_Rx_Buffer[VIRTUAL_COM_PORT_DATA_SIZE];

/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/


u8 DeviceAddress;
//TypeDef_InputPackage IncomingPackage;

extern xQueueHandle Queue_basic_commands;

/*******************************************************************************
* Function Name  : EP1_IN_Callback
* Description    :
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/
void EP1_IN_Callback (void)
{
	Handle_USBAsynchXfer();
}

/*******************************************************************************
* Function Name  : EP3_OUT_Callback
* Description    :
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/
void EP3_OUT_Callback(void)
{
    #define Debug_Command               'd'
    #define SW_Command                  'h'
    #define USB_Idle_Command            'e'
    #define State_Command               's'
    #define UploadConfig_Command        'U'
    #define DownloadConfig_Command      'C'   
    #define Handshake_Command           'R'
    #define IMEI_Command                'I'
    #define Modem_Command               'M'

  
  uint16_t Rx_Cnt;

  /* Get the received data buffer and update the counter */
  Rx_Cnt = USB_SIL_Read(EP3_OUT, USB_Rx_Buffer);




    
    if (USB_Mode==UsbIdleMode || USB_Mode==DebugMode)
    {
      if (*USB_Rx_Buffer==SW_Command) USB_Mode=SWConfigMode;
      if (*USB_Rx_Buffer==Debug_Command) USB_Mode=DebugMode;
      if (*USB_Rx_Buffer==USB_Idle_Command) USB_Mode=UsbIdleMode;
      if (*USB_Rx_Buffer==State_Command) USB_Mode=StateMode;
      if (*USB_Rx_Buffer==UploadConfig_Command) USB_Mode=UploadConfigMode;
      if (*USB_Rx_Buffer==DownloadConfig_Command) {USB_Mode=DownloadConfigMode; Load_Data(USB_Rx_Buffer,Rx_Cnt,1);} //  
      if (*USB_Rx_Buffer==Handshake_Command) USB_Mode=HandshakeMode;
      if (*USB_Rx_Buffer==IMEI_Command) USB_Mode=IMEIMode;
    } 
    else
    {
      if (USB_Mode==DownloadConfigMode)
      {
        Load_Data(USB_Rx_Buffer,Rx_Cnt,0); // 
      }
    }

    //     
    if (USB_Mode==ModemMode)
    {
      USB_Len=Rx_Cnt;
      USB_Data=(char*) USB_Rx_Buffer;
      if (
          (*(USB_Rx_Buffer)=='+') && 
          (*(USB_Rx_Buffer+1)=='+') &&
          (*(USB_Rx_Buffer+2)=='+') 
         ) 
        USB_Mode=UsbIdleMode;  
    }
    
    //     
    if (
          (USB_Mode==UsbIdleMode) &&
          (*(USB_Rx_Buffer)=='M') && 
          (*(USB_Rx_Buffer+1)=='o') &&
          (*(USB_Rx_Buffer+2)=='D') 
        ) 
      USB_Mode=ModemMode;  
  

  /* Enable the receive of data on EP3 */
  SetEPRxValid(ENDP3);
 
}


/*******************************************************************************
* Function Name  : SOF_Callback / INTR_SOFINTR_Callback
* Description    :
* Input          : None.
* Output         : None.
* Return         : None.
*******************************************************************************/
void SOF_Callback(void)
{
  static uint32_t FrameCount = 0;
  
  if(bDeviceState == CONFIGURED)
  {
    if (FrameCount++ == VCOMPORT_IN_FRAME_INTERVAL)
    {
      /* Reset the frame counter */
      FrameCount = 0;
      
      /* Check the data to be sent through IN pipe */

      Handle_USBAsynchXfer();

    }
  }  
}
/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/

