/**
  ******************************************************************************
  * @file    EEPROM_Emulation/inc/eeprom.h 
  * @author  MCD Application Team
  * @version V3.1.0
  * @date    07/27/2009
  * @brief   This file contains all the functions prototypes for the EEPROM 
  *          emulation firmware library.
  ******************************************************************************
  * @copy
  *
  * THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
  * WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE
  * TIME. AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY
  * DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING
  * FROM THE CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE
  * CODING INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2009 STMicroelectronics</center></h2>
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __EEPROM_H
#define __EEPROM_H

/* Includes ------------------------------------------------------------------*/
#include "stm32f10x.h"
#include "Global.h"
    
/* Exported constants --------------------------------------------------------*/
/* Define the STM32F10Xxx Flash page size depending on the used STM32 device */
#if defined (STM32F10X_LD) || defined (STM32F10X_MD)
  #define PAGE_SIZE  (uint16_t)0x400  /* Page size = 1KByte */
#elif defined (STM32F10X_HD) || defined (STM32F10X_CL)
  #define PAGE_SIZE  (uint16_t)0x800  /* Page size = 2KByte */
#endif

/* EEPROM start address in Flash */
#define EEPROM_START_ADDRESS    ((uint32_t)0x0807E000) /* EEPROM emulation start address:
                                                  after 504 KByte of used Flash memory */

/* Pages 0 and 1 base and end addresses */
#define PAGE0_BASE_ADDRESS      ((uint32_t)(EEPROM_START_ADDRESS + 0x000))
#define PAGE0_END_ADDRESS       ((uint32_t)(EEPROM_START_ADDRESS + (PAGE_SIZE - 1)))

#define PAGE1_BASE_ADDRESS      ((uint32_t)(EEPROM_START_ADDRESS + PAGE_SIZE))
#define PAGE1_END_ADDRESS       ((uint32_t)(EEPROM_START_ADDRESS + (2 * PAGE_SIZE - 1)))

/* Used Flash pages for EEPROM emulation */
#define PAGE0                   ((uint16_t)0x0000)
#define PAGE1                   ((uint16_t)0x0001)

/* No valid page define */
#define NO_VALID_PAGE           ((uint16_t)0x00AB)

/* Page status definitions */
#define ERASED                  ((uint16_t)0xFFFF)     /* PAGE is empty */
#define RECEIVE_DATA            ((uint16_t)0xEEEE)     /* PAGE is marked to receive data */
#define VALID_PAGE              ((uint16_t)0x0000)     /* PAGE containing valid data */

/* Valid pages in read and write defines */
#define READ_FROM_VALID_PAGE    ((uint8_t)0x00)
#define WRITE_IN_VALID_PAGE     ((uint8_t)0x01)

/* Page full define */
#define PAGE_FULL               ((uint8_t)0x80)


                                                    
/*    ( 2 )   
Variables' number */
#define NumbOfVar               ((uint8_t)      MAX_DS1820*5 + MAX_RADIO_SENSOR*2 + MAX_IBUTTON*3 + 142)
/*        */
// 16   -1
#define OWNER1_PHONE_W1         ((uint16_t)     1)
#define OWNER1_PHONE_W2         ((uint16_t)     2)
#define OWNER1_PHONE_W3         ((uint16_t)     3)
#define OWNER1_PHONE_W4         ((uint16_t)     4)
#define OWNER1_PHONE_W5         ((uint16_t)     5)
#define OWNER1_PHONE_W6         ((uint16_t)     6)
#define OWNER1_PHONE_W7         ((uint16_t)     7)
#define OWNER1_PHONE_W8         ((uint16_t)     8)
// 16   -2
#define OWNER2_PHONE_W1         ((uint16_t)     9)
#define OWNER2_PHONE_W2         ((uint16_t)     10)
#define OWNER2_PHONE_W3         ((uint16_t)     11)
#define OWNER2_PHONE_W4         ((uint16_t)     12)
#define OWNER2_PHONE_W5         ((uint16_t)     13)
#define OWNER2_PHONE_W6         ((uint16_t)     14)
#define OWNER2_PHONE_W7         ((uint16_t)     15)
#define OWNER2_PHONE_W8         ((uint16_t)     16)
// 16   -3
#define OWNER3_PHONE_W1         ((uint16_t)     17)
#define OWNER3_PHONE_W2         ((uint16_t)     18)
#define OWNER3_PHONE_W3         ((uint16_t)     19)
#define OWNER3_PHONE_W4         ((uint16_t)     20)
#define OWNER3_PHONE_W5         ((uint16_t)     21)
#define OWNER3_PHONE_W6         ((uint16_t)     22)
#define OWNER3_PHONE_W7         ((uint16_t)     23)
#define OWNER3_PHONE_W8         ((uint16_t)     24)  
// 16   -4
#define OWNER4_PHONE_W1         ((uint16_t)     25)
#define OWNER4_PHONE_W2         ((uint16_t)     26)
#define OWNER4_PHONE_W3         ((uint16_t)     27)
#define OWNER4_PHONE_W4         ((uint16_t)     28)
#define OWNER4_PHONE_W5         ((uint16_t)     29)
#define OWNER4_PHONE_W6         ((uint16_t)     30)
#define OWNER4_PHONE_W7         ((uint16_t)     31)
#define OWNER4_PHONE_W8         ((uint16_t)     32)
// 16   -5
#define OWNER5_PHONE_W1         ((uint16_t)     33)
#define OWNER5_PHONE_W2         ((uint16_t)     34)
#define OWNER5_PHONE_W3         ((uint16_t)     35)
#define OWNER5_PHONE_W4         ((uint16_t)     36)
#define OWNER5_PHONE_W5         ((uint16_t)     37)
#define OWNER5_PHONE_W6         ((uint16_t)     38)
#define OWNER5_PHONE_W7         ((uint16_t)     39)
#define OWNER5_PHONE_W8         ((uint16_t)     40)  
// 16   -6
#define OWNER6_PHONE_W1         ((uint16_t)     41)
#define OWNER6_PHONE_W2         ((uint16_t)     42)
#define OWNER6_PHONE_W3         ((uint16_t)     43)
#define OWNER6_PHONE_W4         ((uint16_t)     44)
#define OWNER6_PHONE_W5         ((uint16_t)     45)
#define OWNER6_PHONE_W6         ((uint16_t)     46)
#define OWNER6_PHONE_W7         ((uint16_t)     47)
#define OWNER6_PHONE_W8         ((uint16_t)     48) 
// 16   -7
#define OWNER7_PHONE_W1         ((uint16_t)     49)
#define OWNER7_PHONE_W2         ((uint16_t)     50)
#define OWNER7_PHONE_W3         ((uint16_t)     51)
#define OWNER7_PHONE_W4         ((uint16_t)     52)
#define OWNER7_PHONE_W5         ((uint16_t)     53)
#define OWNER7_PHONE_W6         ((uint16_t)     54)
#define OWNER7_PHONE_W7         ((uint16_t)     55)
#define OWNER7_PHONE_W8         ((uint16_t)     56) 
// 16   -8
#define OWNER8_PHONE_W1         ((uint16_t)     57)
#define OWNER8_PHONE_W2         ((uint16_t)     58)
#define OWNER8_PHONE_W3         ((uint16_t)     59)
#define OWNER8_PHONE_W4         ((uint16_t)     60)
#define OWNER8_PHONE_W5         ((uint16_t)     61)
#define OWNER8_PHONE_W6         ((uint16_t)     62)
#define OWNER8_PHONE_W7         ((uint16_t)     63)
#define OWNER8_PHONE_W8         ((uint16_t)     64) 

// 4-   -
#define PIN_CODE_W1             ((uint16_t)     65)                                                     
#define PIN_CODE_W2             ((uint16_t)     66)

//   
#define MODE_FLAGS_W            ((uint16_t)     67)

//   
#define OUTPUT_STATE_W          ((uint16_t)     68)

// Tmin, Tmax    1
#define RADIO_1_MIN_MAX_W       ((uint16_t)     69)
// Tmin, Tmax    2
#define RADIO_2_MIN_MAX_W       ((uint16_t)     70)
// Tmin, Tmax    3
#define RADIO_3_MIN_MAX_W       ((uint16_t)     71)
// Tmin, Tmax    4
#define RADIO_4_MIN_MAX_W       ((uint16_t)     72)
// Tmin, Tmax    5
#define RADIO_5_MIN_MAX_W       ((uint16_t)     73)
// Tmin, Tmax    6
#define RADIO_6_MIN_MAX_W       ((uint16_t)     74)
// Tmin, Tmax    7
#define RADIO_7_MIN_MAX_W       ((uint16_t)     75)
// Tmin, Tmax    8
#define RADIO_8_MIN_MAX_W       ((uint16_t)     76)
// Tmin, Tmax    9
#define RADIO_9_MIN_MAX_W       ((uint16_t)     77)
// Tmin, Tmax    10
#define RADIO_10_MIN_MAX_W       ((uint16_t)    78)
// Tmin, Tmax    11
#define RADIO_11_MIN_MAX_W       ((uint16_t)    79)
// Tmin, Tmax    12
#define RADIO_12_MIN_MAX_W       ((uint16_t)    80)
// Tmin, Tmax    13
#define RADIO_13_MIN_MAX_W       ((uint16_t)    81)
// Tmin, Tmax    14
#define RADIO_14_MIN_MAX_W       ((uint16_t)    82)
// Tmin, Tmax    15
#define RADIO_15_MIN_MAX_W       ((uint16_t)    83)
// Tmin, Tmax    16
#define RADIO_16_MIN_MAX_W       ((uint16_t)    84)

#define OWNER_1_2_GROUP_W          ((uint16_t)    85)
#define OWNER_3_4_GROUP_W          ((uint16_t)    86)
#define OWNER_5_6_GROUP_W          ((uint16_t)    87)
#define OWNER_7_8_GROUP_W          ((uint16_t)    88)

#define RADIO_LOOP                 ((uint16_t)    89)
#define DS1820_LOOP                ((uint16_t)    90)
#define IBUTTON_LOOP               ((uint16_t)    91)

// Tmin, Tmax DS1820   1
#define DS1820_1_MIN_MAX_W         ((uint16_t)    92)
// Tmin, Tmax DS1820   2
#define DS1820_2_MIN_MAX_W         ((uint16_t)    93)
// Tmin, Tmax DS1820   3
#define DS1820_3_MIN_MAX_W         ((uint16_t)    94)
// Tmin, Tmax DS1820   4
#define DS1820_4_MIN_MAX_W         ((uint16_t)    95)
// Tmin, Tmax DS1820   5
#define DS1820_5_MIN_MAX_W         ((uint16_t)    96)
// Tmin, Tmax DS1820   6
#define DS1820_6_MIN_MAX_W         ((uint16_t)    97)
// Tmin, Tmax DS1820   7
#define DS1820_7_MIN_MAX_W         ((uint16_t)    98)
// Tmin, Tmax DS1820   8
#define DS1820_8_MIN_MAX_W         ((uint16_t)    99)

//     
#define START_T_ADDR		((uint16_t)     100)
// 8-    DS1820  1
#define DS1820_1_W1              ((uint16_t)     START_T_ADDR+0)                                                     
#define DS1820_1_W2              ((uint16_t)     START_T_ADDR+1)
#define DS1820_1_W3              ((uint16_t)     START_T_ADDR+2)                                                     
#define DS1820_1_W4              ((uint16_t)     START_T_ADDR+3)
// 8-    DS1820  2
#define DS1820_2_W1              ((uint16_t)     START_T_ADDR+4)                                                     
#define DS1820_2_W2              ((uint16_t)     START_T_ADDR+5)
#define DS1820_2_W3              ((uint16_t)     START_T_ADDR+6)                                                     
#define DS1820_2_W4              ((uint16_t)     START_T_ADDR+7)

// 8-    DS1820  3
#define DS1820_3_W1              ((uint16_t)     START_T_ADDR+8)                                                     
#define DS1820_3_W2              ((uint16_t)     START_T_ADDR+9)
#define DS1820_3_W3              ((uint16_t)     START_T_ADDR+10)                                                     
#define DS1820_3_W4              ((uint16_t)     START_T_ADDR+11)

// 8-    DS1820  4
#define DS1820_4_W1              ((uint16_t)     START_T_ADDR+12)                                                     
#define DS1820_4_W2              ((uint16_t)     START_T_ADDR+13)
#define DS1820_4_W3              ((uint16_t)     START_T_ADDR+14)                                                     
#define DS1820_4_W4              ((uint16_t)     START_T_ADDR+15)

// 8-    DS1820  5
#define DS1820_5_W1              ((uint16_t)     START_T_ADDR+16)                                                     
#define DS1820_5_W2              ((uint16_t)     START_T_ADDR+17)
#define DS1820_5_W3              ((uint16_t)     START_T_ADDR+18)                                                     
#define DS1820_5_W4              ((uint16_t)     START_T_ADDR+19)

// 8-    DS1820  6
#define DS1820_6_W1              ((uint16_t)     START_T_ADDR+20)                                                     
#define DS1820_6_W2              ((uint16_t)     START_T_ADDR+21)
#define DS1820_6_W3              ((uint16_t)     START_T_ADDR+22)                                                     
#define DS1820_6_W4              ((uint16_t)     START_T_ADDR+23)

// 8-    DS1820  7
#define DS1820_7_W1              ((uint16_t)     START_T_ADDR+24)                                                     
#define DS1820_7_W2              ((uint16_t)     START_T_ADDR+25)
#define DS1820_7_W3              ((uint16_t)     START_T_ADDR+26)                                                     
#define DS1820_7_W4              ((uint16_t)     START_T_ADDR+27)

// 8-    DS1820  8
#define DS1820_8_W1              ((uint16_t)     START_T_ADDR+28)                                                     
#define DS1820_8_W2              ((uint16_t)     START_T_ADDR+29)
#define DS1820_8_W3              ((uint16_t)     START_T_ADDR+30)                                                     
#define DS1820_8_W4              ((uint16_t)     START_T_ADDR+31)

//    IButton
#define START_IBUTTON_ADDR	((uint16_t)     132)
// 6- (48  )  IButton  1
#define IBUTTON_1_W1              ((uint16_t)    START_IBUTTON_ADDR+0)                                                     
#define IBUTTON_1_W2              ((uint16_t)    START_IBUTTON_ADDR+1)
#define IBUTTON_1_W3              ((uint16_t)    START_IBUTTON_ADDR+2)

// 6- (48  )  IButton  2
#define IBUTTON_2_W1              ((uint16_t)    START_IBUTTON_ADDR+3)                                                     
#define IBUTTON_2_W2              ((uint16_t)    START_IBUTTON_ADDR+4)
#define IBUTTON_2_W3              ((uint16_t)    START_IBUTTON_ADDR+5)

// 6- (48  )  IButton  3
#define IBUTTON_3_W1              ((uint16_t)    START_IBUTTON_ADDR+6)                                                     
#define IBUTTON_3_W2              ((uint16_t)    START_IBUTTON_ADDR+7)
#define IBUTTON_3_W3              ((uint16_t)    START_IBUTTON_ADDR+8)

// 6- (48  )  IButton  4
#define IBUTTON_4_W1              ((uint16_t)    START_IBUTTON_ADDR+9)                                                     
#define IBUTTON_4_W2              ((uint16_t)    START_IBUTTON_ADDR+10)
#define IBUTTON_4_W3              ((uint16_t)    START_IBUTTON_ADDR+11)

// 6- (48  )  IButton  5
#define IBUTTON_5_W1              ((uint16_t)    START_IBUTTON_ADDR+12)                                                     
#define IBUTTON_5_W2              ((uint16_t)    START_IBUTTON_ADDR+13)
#define IBUTTON_5_W3              ((uint16_t)    START_IBUTTON_ADDR+14)

// 6- (48  )  IButton  6
#define IBUTTON_6_W1              ((uint16_t)    START_IBUTTON_ADDR+15)                                                     
#define IBUTTON_6_W2              ((uint16_t)    START_IBUTTON_ADDR+16)
#define IBUTTON_6_W3              ((uint16_t)    START_IBUTTON_ADDR+17)

// 6- (48  )  IButton  7
#define IBUTTON_7_W1              ((uint16_t)    START_IBUTTON_ADDR+18)                                                     
#define IBUTTON_7_W2              ((uint16_t)    START_IBUTTON_ADDR+19)
#define IBUTTON_7_W3              ((uint16_t)    START_IBUTTON_ADDR+20)

// 6- (48  )  IButton  8
#define IBUTTON_8_W1              ((uint16_t)    START_IBUTTON_ADDR+21)                                                     
#define IBUTTON_8_W2              ((uint16_t)    START_IBUTTON_ADDR+22)
#define IBUTTON_8_W3              ((uint16_t)    START_IBUTTON_ADDR+23)

// 6- (48  )  IButton  9
#define IBUTTON_9_W1              ((uint16_t)    START_IBUTTON_ADDR+24)                                                     
#define IBUTTON_9_W2              ((uint16_t)    START_IBUTTON_ADDR+25)
#define IBUTTON_9_W3              ((uint16_t)    START_IBUTTON_ADDR+26)

// 6- (48  )  IButton  10
#define IBUTTON_10_W1              ((uint16_t)    START_IBUTTON_ADDR+27)                                                     
#define IBUTTON_10_W2              ((uint16_t)    START_IBUTTON_ADDR+28)
#define IBUTTON_10_W3              ((uint16_t)    START_IBUTTON_ADDR+29)

// 6- (48  )  IButton  11
#define IBUTTON_11_W1              ((uint16_t)    START_IBUTTON_ADDR+30)                                                     
#define IBUTTON_11_W2              ((uint16_t)    START_IBUTTON_ADDR+31)
#define IBUTTON_11_W3              ((uint16_t)    START_IBUTTON_ADDR+32)

// 6- (48  )  IButton  12
#define IBUTTON_12_W1              ((uint16_t)    START_IBUTTON_ADDR+33)                                                     
#define IBUTTON_12_W2              ((uint16_t)    START_IBUTTON_ADDR+34)
#define IBUTTON_12_W3              ((uint16_t)    START_IBUTTON_ADDR+35)

#define IBUTTON_1_2_GROUP_W     ((uint16_t)    168)
#define IBUTTON_3_4_GROUP_W     ((uint16_t)    169)
#define IBUTTON_5_6_GROUP_W     ((uint16_t)    170)
#define IBUTTON_7_8_GROUP_W     ((uint16_t)    171)
#define IBUTTON_9_10_GROUP_W    ((uint16_t)    172)
#define IBUTTON_11_12_GROUP_W   ((uint16_t)    173)

#define DS1820_1_2_GROUP_W      ((uint16_t)    174)
#define DS1820_3_4_GROUP_W      ((uint16_t)    175)
#define DS1820_5_6_GROUP_W      ((uint16_t)    176)
#define DS1820_7_8_GROUP_W      ((uint16_t)    177)

#define TAMPER_220_GROUP_W      ((uint16_t)    178)

#define SMS_ARM_DISARM_W       	((uint16_t)    179)
#define SMS_RING_W           	((uint16_t)    180)
#define ANSWER_ARM_PARAMETER_W 	((uint16_t)    181)
#define RADIO_1_2_GROUP_W       ((uint16_t)    182)
#define RADIO_3_4_GROUP_W       ((uint16_t)    183)
#define RADIO_5_6_GROUP_W       ((uint16_t)    184)
#define RADIO_7_8_GROUP_W       ((uint16_t)    185)
#define RADIO_9_10_GROUP_W      ((uint16_t)    186)
#define RADIO_11_12_GROUP_W     ((uint16_t)    187)
#define RADIO_13_14_GROUP_W     ((uint16_t)    188)
#define RADIO_15_16_GROUP_W     ((uint16_t)    189)
#define GPRS_PERIOD_W   	((uint16_t)    190)
//#define NEXT_PARAMETER_W   	((uint16_t)    191)

//     
#define START_RADIO_ADDR        ((uint16_t)     192)
// 4-    1
#define RADIO_1_W1              ((uint16_t)     START_RADIO_ADDR+0)                                                     
#define RADIO_1_W2              ((uint16_t)     START_RADIO_ADDR+1)
// 4-    2
#define RADIO_2_W1              ((uint16_t)     START_RADIO_ADDR+2)                                                     
#define RADIO_2_W2              ((uint16_t)     START_RADIO_ADDR+3)
// 4-    3
#define RADIO_3_W1              ((uint16_t)     START_RADIO_ADDR+4)                                                     
#define RADIO_3_W2              ((uint16_t)     START_RADIO_ADDR+5)
// 4-    4
#define RADIO_4_W1              ((uint16_t)     START_RADIO_ADDR+6)                                                     
#define RADIO_4_W2              ((uint16_t)     START_RADIO_ADDR+7)
// 4-    5
#define RADIO_5_W1              ((uint16_t)     START_RADIO_ADDR+8)                                                     
#define RADIO_5_W2              ((uint16_t)     START_RADIO_ADDR+9)
// 4-    6
#define RADIO_6_W1              ((uint16_t)     START_RADIO_ADDR+10)                                                     
#define RADIO_6_W2              ((uint16_t)     START_RADIO_ADDR+11)
// 4-    7
#define RADIO_7_W1              ((uint16_t)     START_RADIO_ADDR+12)                                                     
#define RADIO_7_W2              ((uint16_t)     START_RADIO_ADDR+13)
// 4-    8
#define RADIO_8_W1              ((uint16_t)     START_RADIO_ADDR+14)                                                     
#define RADIO_8_W2              ((uint16_t)     START_RADIO_ADDR+15)
// 4-    9
#define RADIO_9_W1              ((uint16_t)     START_RADIO_ADDR+16)                                                     
#define RADIO_9_W2              ((uint16_t)     START_RADIO_ADDR+17)
// 4-    10
#define RADIO_10_W1              ((uint16_t)     START_RADIO_ADDR+18)                                                     
#define RADIO_10_W2              ((uint16_t)     START_RADIO_ADDR+19)
// 4-    11
#define RADIO_11_W1              ((uint16_t)     START_RADIO_ADDR+20)                                                     
#define RADIO_11_W2              ((uint16_t)     START_RADIO_ADDR+21)
// 4-    12
#define RADIO_12_W1              ((uint16_t)     START_RADIO_ADDR+22)                                                     
#define RADIO_12_W2              ((uint16_t)     START_RADIO_ADDR+23)
// 4-    13
#define RADIO_13_W1              ((uint16_t)     START_RADIO_ADDR+24)                                                     
#define RADIO_13_W2              ((uint16_t)     START_RADIO_ADDR+25)
// 4-    14
#define RADIO_14_W1              ((uint16_t)     START_RADIO_ADDR+26)                                                     
#define RADIO_14_W2              ((uint16_t)     START_RADIO_ADDR+27)
// 4-    15
#define RADIO_15_W1              ((uint16_t)     START_RADIO_ADDR+28)                                                     
#define RADIO_15_W2              ((uint16_t)     START_RADIO_ADDR+29)
// 4-    16  
#define RADIO_16_W1              ((uint16_t)     START_RADIO_ADDR+30)                                                     
#define RADIO_16_W2              ((uint16_t)     START_RADIO_ADDR+31)

//     DS1820
#define DS1820_1_2_T_NAGREV_W	((uint16_t)    224)
#define DS1820_3_4_T_NAGREV_W	((uint16_t)    225)
#define DS1820_5_6_T_NAGREV_W	((uint16_t)    226)
#define DS1820_7_8_T_NAGREV_W	((uint16_t)    227)

//    
#define RADIO_1_2_T_NAGREV_W	((uint16_t)    228)
#define RADIO_3_4_T_NAGREV_W	((uint16_t)    229)
#define RADIO_5_6_T_NAGREV_W	((uint16_t)    230)
#define RADIO_7_8_T_NAGREV_W	((uint16_t)    231)
#define RADIO_9_10_T_NAGREV_W	((uint16_t)    232)
#define RADIO_11_12_T_NAGREV_W	((uint16_t)    233)
#define RADIO_13_14_T_NAGREV_W	((uint16_t)    234)
#define RADIO_15_16_T_NAGREV_W	((uint16_t)    235)
//#define NEXT_PARAMETER_W   	((uint16_t)    236)


#define IN_1_2_PARAMETER_W   	((uint16_t)    240)
#define IN_3_4_PARAMETER_W   	((uint16_t)    241)
#define IN_5_6_PARAMETER_W   	((uint16_t)    242)
#define IN_7_8_PARAMETER_W   	((uint16_t)    243)
#define RADIO_1_2_PARAMETER_W   ((uint16_t)    244)
#define RADIO_3_4_PARAMETER_W   ((uint16_t)    245)
#define RADIO_5_6_PARAMETER_W   ((uint16_t)    246)
#define RADIO_7_8_PARAMETER_W   ((uint16_t)    247)
#define RADIO_9_10_PARAMETER_W  ((uint16_t)    248)
#define RADIO_11_12_PARAMETER_W ((uint16_t)    249)
#define RADIO_13_14_PARAMETER_W ((uint16_t)    250)
#define RADIO_15_16_PARAMETER_W ((uint16_t)    251)
#define IN_1_2_GROUP_W   	((uint16_t)    252)
#define IN_3_4_GROUP_W   	((uint16_t)    253)
#define IN_5_6_GROUP_W   	((uint16_t)    254)
#define IN_7_8_GROUP_W   	((uint16_t)    255)                                                     
//END!!!
//********************** END OF EEPROM!!!

/* Exported types ------------------------------------------------------------*/
/* Exported macro ------------------------------------------------------------*/
/* Exported functions ------------------------------------------------------- */
uint16_t EE_Init(void);
uint16_t EE_ReadVariable(uint16_t VirtAddress, uint16_t* Data);
uint16_t EE_WriteVariable(uint16_t VirtAddress, uint16_t Data);
void EEPROM_Format (void);


#endif /* __EEPROM_H */

/******************* (C) COPYRIGHT 2009 STMicroelectronics *****END OF FILE****/
