
#include "libraries.h"
extern xQueueHandle 			Queue_Print_Debug, Queue_Event, Queue_GPRS_Event, Queue_Delay_Event, Queue_TRX_Command;
extern xSemaphoreHandle                 Mutex_Flash_Access, Mutex_Copy_Delay_Event, Mutex_Save_Event, xSemaphore_GSM_UART_Handler;
extern xTaskHandle                      pxTask_I_O_TIMERS;
extern xTaskHandle                      pxTask_ADC;
extern xTaskHandle                      pxTask_1WIRE_1;
extern xTaskHandle                      pxTask_1WIRE_2;
extern xTaskHandle                      pxTask_SPI;
extern xTaskHandle                      pxTask_RS485;
extern xTaskHandle                      pxTask_PRINT_DEBUG;
extern xTaskHandle                      pxTask_GSM, pxTask_GSM_Data_Analize;
extern xTaskHandle                      pxTask_CORE_IDLE;

extern volatile char                    Mode_Flag[];
extern volatile char                    Working_Flag[];
extern volatile TypeDef_USB_Mode        USB_Mode;
extern uint32_t                         Device_Serial_0, Device_Serial_1, Device_Serial_2;
/*******************************************************************************
* Function Name  : main
* Description    :   ,     
                    FreeRTOS
* Input          : None
* Output         : None
* Return         : None
*******************************************************************************/ 
void main()
{ 

    /* JTAG-DP Disabled and SW-DP Enabled */
    PreInit();
 
    /*    */
    Hardware_Init();

    /* Unlock the Flash Program Erase controller */
    FLASH_Unlock();
   
      
    // ID
    Device_Serial_0 = *(__IO uint32_t*)(0x1FFFF7E8);
    Device_Serial_1 = *(__IO uint32_t*)(0x1FFFF7EC);
    Device_Serial_2 = *(__IO uint32_t*)(0x1FFFF7F0);
  
    /*   */
    FLASH_ReadOutProtection(ENABLE);      

     /* Flash Init */
    Flash_Init( * (uint32_t *) FLASH_VALIDITY_ADDRESS);
    
    /* EEPROM Init */
    EE_Init();

    /* Lock the Flash Program Erase controller */ 
    FLASH_Lock();   
    
    /*  Watch Dog */
    WatchDog_Init();
    
    /*      DEBUG-,   "" */ 
    Queue_Print_Debug = xQueueCreate(MAX_PRINT_DEBUG_EVENTS, sizeof(TypeDef_PRINT_DEBUG) );

    /*    */ 
    Queue_Event = xQueueCreate(EVENT_QUEUE_LEN, sizeof(TypeDef_EVENT) );

    /*     */ 
    Queue_GPRS_Event = xQueueCreate(GPRS_EVENT_QUEUE_LEN, sizeof(TypeDef_GPRS_EVENT) );

    /*      */ 
    Queue_Delay_Event = xQueueCreate(DELAY_EVENT_QUEUE_LEN, sizeof(TypeDef_DELAY_EVENT) );

    /*       -RFM */ 
    Queue_TRX_Command = xQueueCreate(8, sizeof(char) );
    
    /*          Flash- (     EEPROM) */
    Mutex_Flash_Access=xSemaphoreCreateMutex();    

    /*         ""      */
    Mutex_Copy_Delay_Event=xSemaphoreCreateMutex(); 

    /*            ,     */
    Mutex_Save_Event=xSemaphoreCreateMutex(); 
    
    /*           GSM_UART */
    vSemaphoreCreateBinary( xSemaphore_GSM_UART_Handler );
    
/*    ,      . */    
if (    Mutex_Copy_Delay_Event!=NULL && 
        Mutex_Flash_Access!=NULL  && 
        Mutex_Save_Event!=NULL  &&
        Queue_Print_Debug!=NULL && 
	Queue_GPRS_Event!=NULL &&
        Queue_Event!=NULL &&
        Queue_TRX_Command!=NULL &&
        xSemaphore_GSM_UART_Handler!=NULL
    )
  {    
     /*        */
    xTaskCreate( Task_CORE_IDLE, ( signed char * ) "Task_CORE_IDLE", TASK_CORE_IDLE_STACK_SIZE, NULL, TASK_CORE_IDLE_PRIORITY, & pxTask_CORE_IDLE);
  
    /*    ,  , - */
    xTaskCreate( Task_I_O_TIMERS, ( signed char * ) "Task_I_O_TIMERS", TASK_I_O_TIMERS_STACK_SIZE, NULL, TASK_I_O_TIMERS_PRIORITY, & pxTask_I_O_TIMERS);

#if !defined (ADC_BLOCKED)    
    /*   ADC */
    xTaskCreate( Task_ADC, ( signed char * ) "Task_ADC", TASK_ADC_STACK_SIZE, NULL, TASK_ADC_PRIORITY, & pxTask_ADC);
#endif 
    
#if !defined (_1WIRE_1_BLOCKED)
    /*    I-Button  1Wire_1  */
    xTaskCreate( Task_1WIRE_1, ( signed char * ) "Task_1WIRE_1", TASK_1WIRE_1_STACK_SIZE, NULL, TASK_1WIRE_1_PRIORITY, & pxTask_1WIRE_1);
#endif 
    
#if !defined (_1WIRE_2_BLOCKED)  
    /*    DS1820  1Wire_2 */
    xTaskCreate( Task_1WIRE_2, ( signed char * ) "Task_1WIRE_2", TASK_1WIRE_2_STACK_SIZE, NULL, TASK_1WIRE_2_PRIORITY, & pxTask_1WIRE_2);
#endif 
    
#if !defined (SPI_BLOCKED)   
    /*     SPI */
    xTaskCreate( Task_SPI, ( signed char * ) "Task_SPI", TASK_SPI_STACK_SIZE, NULL, TASK_SPI_PRIORITY, & pxTask_SPI);
#endif 
    
#if !defined (RS485_BLOCKED)  
    /*     RS485 */
    xTaskCreate( Task_RS485, ( signed char * ) "Task_RS485", TASK_RS485_STACK_SIZE, NULL, TASK_RS485_PRIORITY, & pxTask_RS485);
#endif  
  
    /* -   DEBUG-  DEBUG- (USB) */
    xTaskCreate( Task_PRINT_DEBUG, ( signed char * ) "Task_PRINT_DEBUG", TASK_PRINT_DEBUG_STACK_SIZE, NULL, TASK_PRINT_DEBUG_PRIORITY, & pxTask_PRINT_DEBUG);

  
    /*     GSM- */
    xTaskCreate( Task_GSM, ( signed char * ) "Task_GSM", TASK_GSM_STACK_SIZE, NULL, TASK_GSM_PRIORITY, & pxTask_GSM);

    /*      GSM-,    UART */
    xTaskCreate( Task_GSM_Data_Analize, ( signed char * ) "Task_GSM_Data_Analize", TASK_GSM_STACK_SIZE, NULL, TASK_GSM_PRIORITY, & pxTask_GSM_Data_Analize);

    
    /*  ,       . */
    vTaskStartScheduler();
  }

  /*   ,    main()      ,
          .  main()  
       ,    ,     
     (heap)      (idle task) */



  while (1)
  {}
  
}


/*******************************************************************************
* Function Name  : PreInit
* Description    : Disable JTAG
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
static void PreInit(void) {
  GPIO_InitTypeDef GPIO_InitStructure;

  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA | RCC_APB2Periph_AFIO, ENABLE);
  RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOB | RCC_APB2Periph_AFIO, ENABLE);
   
  /* JTAG-DP Disabled and SW-DP Enabled */
  GPIO_PinRemapConfig(GPIO_Remap_SWJ_JTAGDisable, ENABLE); 
  
  /*Full SWJ Disabled (JTAG-DP + SW-DP)*/
  //GPIO_PinRemapConfig(GPIO_Remap_SWJ_Disable, ENABLE); // Disable JTAG/SWD pins 
  
  //     JTDI     0
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_15;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
  GPIOA->BRR = (GPIO_Pin_15); // set 0
  
   //     JTDO,JTRST     0
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_3 | GPIO_Pin_4;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_Init(GPIOB, &GPIO_InitStructure);
  GPIOB->BRR = (GPIO_Pin_3 | GPIO_Pin_4 ); // set 0
  
}

/*******************************************************************************
* Function Name  : Hardware_Init
* Description    : 
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void Hardware_Init(void)
{
    USB_Config();
    InPins_Config();
    OutPins_Config();
    SIM900_Config();
    
#if !defined (RS485_BLOCKED)    
    RS485_Config();
#endif
    
#if !defined (_1WIRE_1_BLOCKED)
    _1Wire_1_Config();
#endif
    
#if !defined (_1WIRE_2_BLOCKED)    
    _1Wire_2_Config();
#endif
    
#if !defined (SPI_BLOCKED)    
    SPI_Config();
#endif
    
#if !defined (ADC_BLOCKED)    
    ADC_Config();
#endif
    
#if !defined (RTC_BLOCKED)   
    RTC_Config();
#endif
    
    test(); // 
}

/*******************************************************************************
* Function Name  : USB_Config
* Description    : 
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void USB_Config() 
{ 
	Set_System();
	Set_USBClock();
	USB_Interrupts_Config();
	USB_Init();
}


/*******************************************************************************
* Function Name  : OutPins_Config
* Description    : 
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void OutPins_Config()
{
  
  GPIO_InitTypeDef GPIO_InitStructure;
  

  RCC_APB2PeriphClockCmd(LED_APB_CLOCK , ENABLE);
  GPIO_InitStructure.GPIO_Pin = LED_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init( LED_PORT , &GPIO_InitStructure);
  
    
  RCC_APB2PeriphClockCmd(SIRENA_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = SIRENA_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(SIRENA_PORT, &GPIO_InitStructure); 
 
  RCC_APB2PeriphClockCmd(OUT1_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = OUT1_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(OUT1_PORT, &GPIO_InitStructure);
 
  RCC_APB2PeriphClockCmd(OUT2_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = OUT2_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(OUT2_PORT, &GPIO_InitStructure);
 
  
  RCC_APB2PeriphClockCmd(OUT3_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = OUT3_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(OUT3_PORT, &GPIO_InitStructure);
 
  RCC_APB2PeriphClockCmd(OUT4_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = OUT4_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(OUT4_PORT, &GPIO_InitStructure);

 #ifndef OKO_U2 
  RCC_APB2PeriphClockCmd(OUT5_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = OUT5_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(OUT5_PORT, &GPIO_InitStructure);
   
  RCC_APB2PeriphClockCmd(OUT6_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = OUT6_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(OUT6_PORT, &GPIO_InitStructure);
   
  RCC_APB2PeriphClockCmd(OUT7_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = OUT7_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(OUT7_PORT, &GPIO_InitStructure);
 
  RCC_APB2PeriphClockCmd(OUT8_APB_CLOCK, ENABLE);  
  GPIO_InitStructure.GPIO_Pin = OUT8_PIN;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(OUT8_PORT, &GPIO_InitStructure);
#endif 
  
}
/*******************************************************************************
* Function Name  : InPins_Config
* Description    : 
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void InPins_Config()
{
  GPIO_InitTypeDef GPIO_InitStructure;

  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPU;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;

  RCC_APB2PeriphClockCmd(BUTTON_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = BUTTON_PIN;
  GPIO_Init(BUTTON_PORT, &GPIO_InitStructure);
  
  RCC_APB2PeriphClockCmd(IN1_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = IN1_PIN;
  GPIO_Init(IN1_PORT, &GPIO_InitStructure);

  RCC_APB2PeriphClockCmd(IN2_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = IN2_PIN;
  GPIO_Init(IN2_PORT, &GPIO_InitStructure);
  
  RCC_APB2PeriphClockCmd(IN3_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = IN3_PIN;
  GPIO_Init(IN3_PORT, &GPIO_InitStructure);
 
  RCC_APB2PeriphClockCmd(IN4_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = IN4_PIN;
  GPIO_Init(IN4_PORT, &GPIO_InitStructure);

#ifdef OKO_U2 
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_IPD;
#endif  
  
  RCC_APB2PeriphClockCmd(IN5_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = IN5_PIN;
  GPIO_Init(IN5_PORT, &GPIO_InitStructure);
 
  RCC_APB2PeriphClockCmd(IN6_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = IN6_PIN;
  GPIO_Init(IN6_PORT, &GPIO_InitStructure);
  
  RCC_APB2PeriphClockCmd(IN7_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = IN7_PIN;
  GPIO_Init(IN7_PORT, &GPIO_InitStructure);

  RCC_APB2PeriphClockCmd(IN8_APB_CLOCK, ENABLE);
  GPIO_InitStructure.GPIO_Pin = IN8_PIN;
  GPIO_Init(IN8_PORT, &GPIO_InitStructure);

  
  
 
}


/*******************************************************************************
* Function Name  : USB_LP_CAN1_RX0_IRQHandler
* Description    : 
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void USB_LP_CAN1_RX0_IRQHandler(void)
{
  USB_Istr();
}

/*******************************************************************************
* Function Name  : RTC_Config
* Description    : Configures the RTC
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void RTC_Config(void)
{
    uint16_t StartUpCounter = 0x0500;
    NVIC_InitTypeDef NVIC_InitStructure;
    
    /* Enable the RTC Interrupt */
    NVIC_InitStructure.NVIC_IRQChannel = RTC_IRQn;
    NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 1;
    NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
    NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
    NVIC_Init(&NVIC_InitStructure);  
  
    /* Enable PWR and BKP clocks */
    RCC_APB1PeriphClockCmd(RCC_APB1Periph_PWR | RCC_APB1Periph_BKP, ENABLE);

    /* Allow access to BKP Domain */
    PWR_BackupAccessCmd(ENABLE);

    
    /* Reset Backup Domain */
    RCC_BackupResetCmd(ENABLE);
    RCC_BackupResetCmd(DISABLE);

    /* Enable LSE */
    RCC_LSEConfig(RCC_LSE_ON);
    /* Wait till LSE is ready */
    while (RCC_GetFlagStatus(RCC_FLAG_LSERDY) == RESET  &&  StartUpCounter!=0)
    {StartUpCounter--;}

    /* Select LSE as RTC Clock Source */
    RCC_RTCCLKConfig(RCC_RTCCLKSource_LSE);

    /* Enable RTC Clock */
    RCC_RTCCLKCmd(ENABLE);

    /* Wait for RTC registers synchronization */
    RTC_WaitForSynchro();

    /* Wait until last write operation on RTC registers has finished */
    RTC_WaitForLastTask();

    /* Enable the RTC Second */
    RTC_ITConfig(RTC_IT_SEC, ENABLE);

    /* Wait until last write operation on RTC registers has finished */
    RTC_WaitForLastTask();

    /* Set RTC prescaler: set RTC period to 1sec */
    RTC_SetPrescaler(32767); /* RTC period = RTCCLK/RTC_PR = (32.768 KHz)/(32767+1) */

    /* Wait until last write operation on RTC registers has finished */
    RTC_WaitForLastTask();
}


/*******************************************************************************
* Function Name  : RTC_IRQHandler
* Description    : This function handles RTC global interrupt request
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void RTC_IRQHandler(void)
{
    if (RTC_GetITStatus(RTC_IT_SEC) != RESET)
    {
      /* Clear the RTC Second interrupt */
      RTC_ClearITPendingBit(RTC_IT_SEC);

        /* Toggle LED 
      if (LED_STATE!= RESET) 
      {
         LED_OFF; 
      }
      else
      {
         LED_ON; 
      } 
      */

        /* Wait until last write operation on RTC registers has finished */
        RTC_WaitForLastTask();
    }
}

/*******************************************************************************
* Function Name  : vApplicationStackOverflowHook
* Description    :     . 
*                        
*                FreeRTOSConfig.h  configCHECK_FOR_STACK_OVERFLOW=2  ,  =0 
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void vApplicationStackOverflowHook( xTaskHandle *pxTask, signed portCHAR *pcTaskName )
{
  
  if (pxTask_I_O_TIMERS==pxTask) OUT1_ON
   else
     if (pxTask_ADC==pxTask) OUT2_ON
      else
        if (pxTask_1WIRE_1==pxTask) OUT3_ON
          else
            if (pxTask_1WIRE_2==pxTask) OUT4_ON
              else
              #ifndef OKO_U2
                if (pxTask_SPI==pxTask) OUT5_ON
                  else
                    if (pxTask_RS485==pxTask) OUT6_ON
                      else
                        if (pxTask_PRINT_DEBUG==pxTask) OUT7_ON
                          else
                            if (pxTask_GSM==pxTask) OUT8_ON
                              else
              #endif
                              { 
                                OUT1_ON; OUT2_ON; OUT3_ON; OUT4_ON; 
                                #ifndef OKO_U2
                                OUT5_ON; OUT6_ON; OUT7_ON; OUT8_ON;
                                #endif
                              }
  

 /* 
  portBASE_TYPE xStatus;
  TypeDef_PRINT_DEBUG xMessage; 
                              
  if (USB_Mode==DebugMode)
   {
 

    xMessage.Debug_Data_Len = configMAX_TASK_NAME_LEN;
    xMessage.Debug_Source_ID = StackOverflow_Debug_ID;
    xMessage.Debug_Char_Data = (char *) pcTaskName;
    xMessage.Debug_Data_type=Debug_Data_type_ASCII;
        

    xStatus = xQueueSendToBackFromISR(Queue_Print_Debug, &xMessage, 0 );
    if( xStatus != pdPASS )
     {

       
         
     }
     

    
   }
*/
  
}

void TIM5_ConfigForLSI(void)
{
  NVIC_InitTypeDef NVIC_InitStructure;
  TIM_ICInitTypeDef  TIM_ICInitStructure;

  /* Enable TIM5 clocks */
  RCC_APB1PeriphClockCmd(RCC_APB1Periph_TIM5, ENABLE);
  
  /* Enable the TIM5 Interrupt */
  NVIC_InitStructure.NVIC_IRQChannel = TIM5_IRQn;
  NVIC_InitStructure.NVIC_IRQChannelPreemptionPriority = 1;
  NVIC_InitStructure.NVIC_IRQChannelSubPriority = 0;
  NVIC_InitStructure.NVIC_IRQChannelCmd = ENABLE;
  NVIC_Init(&NVIC_InitStructure);

  /* Configure TIM5 prescaler */
  TIM_PrescalerConfig(TIM5, 0, TIM_PSCReloadMode_Immediate);

  /* Connect internally the TM5_CH4 Input Capture to the LSI clock output */
  GPIO_PinRemapConfig(GPIO_Remap_TIM5CH4_LSI, ENABLE);
  
  /* TIM5 configuration: Input Capture mode ---------------------
     The LSI oscillator is connected to TIM5 CH4
     The Rising edge is used as active edge,
     The TIM5 CCR4 is used to compute the frequency value 
  ------------------------------------------------------------ */
  TIM_ICInitStructure.TIM_Channel = TIM_Channel_4;
  TIM_ICInitStructure.TIM_ICPolarity = TIM_ICPolarity_Rising;
  TIM_ICInitStructure.TIM_ICSelection = TIM_ICSelection_DirectTI;
  TIM_ICInitStructure.TIM_ICPrescaler = TIM_ICPSC_DIV8;
  TIM_ICInitStructure.TIM_ICFilter = 0;
  TIM_ICInit(TIM5, &TIM_ICInitStructure);
  
  /* TIM10 Counter Enable */
  TIM_Cmd(TIM5, ENABLE);

  /* Reset the flags */
  TIM5->SR = 0;
    
  /* Enable the CC4 Interrupt Request */  
  TIM_ITConfig(TIM5, TIM_IT_CC4, ENABLE);  
}

/*******************************************************************************
* Function Name  : WatchDog_Init
* Description    :  Watch Dog 
* Input          : 
* Output         : 
* Return         : 
*******************************************************************************/
void WatchDog_Init(void)
{
  __IO uint32_t LsiFreq = 40000;
  
  /* Check if the system has resumed from IWDG reset */
  if (RCC_GetFlagStatus(RCC_FLAG_IWDGRST) != RESET)
  {
    /* IWDGRST flag set */
    
    FLAG_WATCH_DOG_SET;

    /* Clear reset flags */
    RCC_ClearFlag();
  }
  else
  {
    /* IWDGRST flag is not set */
    
    
  } 
 
  /* Enable the LSI OSC */
  RCC_LSICmd(ENABLE);
  
  /* Wait till LSI is ready */
  while (RCC_GetFlagStatus(RCC_FLAG_LSIRDY) == RESET)
  {}
  
  /* TIM Configuration -------------------------------------------------------*/
  TIM5_ConfigForLSI();
  
  /* Wait until the TIM5 get 2 LSI edges */
  //while(CaptureNumber != 2)
  //{
  //}

  /* Disable TIM5 CC4 Interrupt Request */
  TIM_ITConfig(TIM5, TIM_IT_CC4, DISABLE);

  /* IWDG timeout equal to 250 ms (the timeout may varies due to LSI frequency
     dispersion) */
  /* Enable write access to IWDG_PR and IWDG_RLR registers */
  IWDG_WriteAccessCmd(IWDG_WriteAccess_Enable);

  /* IWDG counter clock: LSI/128 */
  IWDG_SetPrescaler(IWDG_Prescaler_128); //IWDG_Prescaler  40kHz/128= 3.2mc

  IWDG_SetReload(2000); //2000*3.2mc = 6.4sec, MAX 4096 (0xFFF)

  /* Reload IWDG counter */
  IWDG_ReloadCounter();

  /* Enable IWDG (the LSI oscillator will be enabled by hardware) */
#if !defined  (WD_DISABLE)
  IWDG_Enable();
#endif
  
  
}
