
#ifndef _TASK_PRINT_DEBUG_
  #define _TASK_PRINT_DEBUG_

/*   DEBUG- */
  #define MAX_PRINT_DEBUG_EVENTS                        20

/*     , mc */
  #define DEBUG_WAIT                                    50 

/*   ""  , *100 mc */
  #define CHECK_TASKS_LEN                               600

/*Debug_Data_type -   :bin,hex,ASCII,Long */
  #define Debug_Data_type_BIN                           0
  #define Debug_Data_type_HEX                           1
  #define Debug_Data_type_2HEX                          2
  #define Debug_Data_type_ASCII                         3
  #define Debug_Data_type_LONG                          4

/*Debug_Source_ID -    */
  #define Core_Idle_Debug_ID                            0
  #define Send_1Wire_1_Debug_ID                         1
  #define Receive_1Wire_1_Debug_ID                      2
  #define Send_1Wire_2_Debug_ID                         3
  #define Receive_1Wire_2_Debug_ID                      4
  #define SendSPI_Debug_ID                              5
  #define ReceiveSPI_Debug_ID                           6
  #define SendRS485_Debug_ID                            7
  #define ReceiveRS485_Debug_ID                         8
  #define Send_Command_To_SIM900_Debug_ID               9
  #define ReceiveDataFromSIM900_Debug_ID                10 
  #define ADC_Debug_ID                                  11 
  #define Inputs_Debug_ID                               12 
  #define System_Debug_ID                               13 
  #define Test_Debug_ID                                 14 
  #define StackOverflow_Debug_ID                        15 
  #define DS1820_Debug_ID                               16

/*     HexToCharExt -  HEX  ASCII*/
  #define HEX_TO_CHAR_DATA_TYPE               unsigned long int

/**
 * @brief Unique ID register address location
 */
  #define ID_UNIQUE_ADDRESS		0x1FFF7A10

/**
 * @brief Flash size register address
 */
  #define ID_FLASH_ADDRESS		0x1FFF7A22

/**
 * @brief Device ID register address
 */
  #define ID_DBGMCU_IDCODE		0xE0042000
/**
 * @brief  Get STM32F4xx device signature
 * @note   Defined as macro to get maximal response time
 * @param  None
 * @retval Device signature, bits 11:0 are valid, 15:12 are always 0.
 *           - 0x0413: STM32F405xx/07xx and STM32F415xx/17xx)
 *           - 0x0419: STM32F42xxx and STM32F43xxx
 *           - 0x0423: STM32F401xB/C
 *           - 0x0433: STM32F401xD/E
 *           - 0x0431: STM32F411xC/E
 */
#define TM_ID_GetSignature()	((*(uint16_t *) (ID_DBGMCU_IDCODE)) & 0x0FFF)

/**
 * @brief  Get STM32F4xx device revision
 * @note   Defined as macro to get maximal response time
 * @param  None
 * @retval Device revision value
 *           - 0x1000: Revision A
 *           - 0x1001: Revision Z
 *           - 0x1003: Revision Y
 *           - 0x1007: Revision 1
 *           - 0x2001: Revision 3
 */
#define TM_ID_GetRevision()		(*(uint16_t *) (DBGMCU->IDCODE + 2))

/**
 * @brief  Get STM32F4xx device's flash size in kilo bytes
 * @note   Defined as macro to get maximal response time
 * @param  None
 * @retval Flash size in kilo bytes
 */
#define TM_ID_GetFlashSize()	(*(uint16_t *) (ID_FLASH_ADDRESS))

/**
 * @brief  Get unique ID number in 8-bit format
 * @note   STM32F4xx has 96bits long unique ID, so 12 bytes are available for read in 8-bit format
 * @note   Defined as macro to get maximal response time
 * @param  x: Byte number: specify which part of 8 bits you want to read
 *               - Values between 0 and 11 are allowed
 * @retval Unique ID address
 */
#define TM_ID_GetUnique8(x)		((x >= 0 && x < 12) ? (*(uint8_t *) (ID_UNIQUE_ADDRESS + (x))) : 0)
	
/**
 * @brief  Get unique ID number in 16-bit format
 * @note   STM32F4xx has 96bits long unique ID, so 6 2-bytes values are available for read in 16-bit format
 * @note   Defined as macro to get maximal response time
 * @param  x: Byte number: specify which part of 16 bits you want to read
 *               - Values between 0 and 5 are allowed
 * @retval Unique ID address
 */
#define TM_ID_GetUnique16(x)	((x >= 0 && x < 6) ? (*(uint16_t *) (ID_UNIQUE_ADDRESS + 2 * (x))) : 0)

/**
 * @brief  Get unique ID number in 32-bit format
 * @note   STM32F4xx has 96bits long unique ID, so 3 4-bytes values are available for read in 32-bit format
 * @note   Defined as macro to get maximal response time
 * @param  x: Byte number: specify which part of 16 bits you want to read
 *               - Values between 0 and 2 are allowed
 * @retval Unique ID address
 */
#define TM_ID_GetUnique32(x)	((x >= 0 && x < 3) ? (*(uint32_t *) (ID_UNIQUE_ADDRESS + 4 * (x))) : 0)

/**
 * @}
 */

  void HexToChar (char *result , char input);
  void HexToCharExt (char *result, HEX_TO_CHAR_DATA_TYPE input);

  void Task_PRINT_DEBUG( void *pvParameters );
 
  
  
#endif